@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0200';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -31,6 +31,13 @@ has octave => (
 );
 
 
+has scale => (
+    is  => 'ro',
+    isa => sub { croak 'not a code reference' unless ref $_[0] eq 'CODE' },
+    default => sub { sub { $_[0] =~ /^[A-G][#b]?m/ ? 'minor' : 'major' } },
+);
+
+
 has verbose => (
     is  => 'ro',
     isa => sub { croak 'not a boolean' unless $_[0] =~ /^[01]$/ },
@@ -46,7 +53,7 @@ sub generate {
 
     print "* CHORD: $chord\n" if $self->verbose;
 
-    my $scale = $chord =~ /^[A-G][#b]?m/ ? 'minor' : 'major';
+    my $scale = $self->scale->($chord);
 
     # Parse the chord
     my $chord_note;
@@ -149,7 +156,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0106
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -197,6 +204,20 @@ Lowest MIDI octave.
 
 Default: C<2>
 
+=head2 scale
+
+  $scale = $bassline->scale;
+
+The musical scale to use.
+
+Default: C<sub { $_[0] =~ /^[A-G][#b]?m/ ? 'minor' : 'major' }>
+
+Alternatives:
+
+  sub { 'chromatic' }
+
+  sub { $_[0] =~ /^[A-G][#b]?m/ ? 'pminor' : 'pentatonic' }
+
 =head2 verbose
 
   $verbose = $bassline->verbose;
@@ -212,6 +233,7 @@ Default: C<0>
   $bassline = MIDI::Bassline::Walk->new(
       intervals => $intervals,
       octave    => $octave,
+      scale     => $scale,
       verbose   => $verbose,
   );
 
